# The COPYRIGHT file at the top level of this repository contains the full
# copyright notices and license terms.
import unittest
import trytond.tests.test_tryton
from trytond.tests.test_tryton import ModuleTestCase
from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT
from trytond.transaction import Transaction
from trytond.exceptions import UserError
import doctest
from trytond.tests.test_tryton import doctest_setup, doctest_teardown


class StockProductCategoryLocationTestCase(ModuleTestCase):
    """Test Stock Product Category Location module"""
    module = 'stock_product_category_location'

    def setUp(self):
        super(StockProductCategoryLocationTestCase, self).setUp()
        self.location = POOL.get('stock.location')
        self.category = POOL.get('product.category')
        self.cat_loc = POOL.get('stock.product.category.location')

    def test0010_add_category_default_location(self):
        """Add the category default location for a warehouse"""

        with Transaction().start(DB_NAME, USER, context=CONTEXT) as transaction:
            storage, = self.location.search([('code', '=', 'STO')])
            new_cat, = self.category.create([{'name': 'CAT1'}])
            cat_loc_rec = {
                'category': new_cat.id,
                'warehouse': storage.parent.id,
                'location': storage.id
            }
            self.cat_loc.create([cat_loc_rec])
            transaction.cursor.commit()

    def test0020category_location_unique(self):
        """Check unique error"""

        with Transaction().start(DB_NAME, USER, context=CONTEXT):
            storage, = self.location.search([('code', '=', 'STO')])
            new_cat, = self.category.search([('name', '=', 'CAT1')])
            cat_loc_rec = {
                'category': new_cat.id,
                'warehouse': storage.parent.id,
                'location': storage.id
            }
            with self.assertRaises(UserError) as cm:
                self.cat_loc.create([cat_loc_rec])
            self.assertEqual(
                cm.exception.message, 'Category and location must be unique.')


def suite():
    suite = trytond.tests.test_tryton.suite()
    suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
        StockProductCategoryLocationTestCase))
    suite.addTests(doctest.DocFileSuite('scenario_stock_product_category_location.rst',
                                        setUp=doctest_setup, tearDown=doctest_teardown, encoding='utf-8',
                                        optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
    return suite
